@@ -1,4 +1,4 @@
-#!C:/msys64/clangarm64/bin/python
+#!/usr/bin/env python3
 #
 # Copyright 2018 Ettus Research, a National Instruments Company
 # Copyright 2020 Ettus Research, a National Instruments Brand
@@ -44,6 +44,7 @@ import sys
 import tempfile
 import zipfile
 import platform
+import subprocess
 from urllib.parse import urljoin  # Python 3
 
 # For all the non-core-library imports, we will be extra paranoid and be very
@@ -64,13 +65,15 @@ _USERNAME_VARIABLE        = "UHD_IMAGES_USER"
 _PASSWORD_VARIABLE        = "UHD_IMAGES_PASSWORD"
 _DEFAULT_TARGET_REGEX     = "(fpga|fw|windrv)_default"
 _BASE_DIR_STRUCTURE_PARTS = ["share", "uhd", "images"]
-_DEFAULT_INSTALL_PATH     = os.path.join("/clangarm64", *_BASE_DIR_STRUCTURE_PARTS)
+_DEFAULT_INSTALL_PATH_UNIX = os.path.join("/clangarm64", *_BASE_DIR_STRUCTURE_PARTS)
+_DEFAULT_INSTALL_PATH     = subprocess.check_output(["cygpath.exe", "-m",
+                            _DEFAULT_INSTALL_PATH_UNIX]).decode('utf-8').strip()
 _DEFAULT_BASE_URL         = "https://files.ettus.com/binaries/cache/"
 _INVENTORY_FILENAME       = "inventory.json"
 _DEFAULT_BUFFER_SIZE      = 8192
 _DEFAULT_DOWNLOAD_LIMIT   = 1024 * 1024 * 1024 # Bytes
 _ARCHIVE_DEFAULT_TYPE     = "zip"
-_UHD_VERSION              = "4.7.0.0-0-16be3bf0"
+_UHD_VERSION              = "4.7.0.0-0-708c5892"
 _LOG_LEVELS = {
     "TRACE": 1,
     "DEBUG": 2,
